[![PyPI - Downloads](https://img.shields.io/pypi/v/pylidc.svg?color=green&label=version&style=flat-square)](https://pypi.org/project/pylidc/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pylidc.svg?color=yellow&label=downloads&style=flat-square)](https://pypistats.org/packages/pylidc)

`pylidc` is a python library intended to improve workflow associated with the [LIDC dataset](https://wiki.cancerimagingarchive.net/display/Public/LIDC-IDRI).

Install via pip: `pip install pylidc`.

[See the full documentation and tutorials here.](https://pylidc.github.io)
